==> v2.10.0.zip: privacyguides.org/docs/news-aggregators.en.md <==
---
title: "News Aggregators"
icon: octicons/rss-24
---

A [news aggregator](https://en.wikipedia.org/wiki/News_aggregator) is a way to keep up with your favourite blogs and news sites.

## Aggregator clients

### Fluent Reader

!!! recommendation

    ![Fluent Reader logo](assets/img/news-aggregators/fluent-reader.svg){ align=right }

    **Fluent Reader** is a secure cross-platform news aggregator that has useful privacy features such as deletion of cookies on exit, strict [content security policies (CSP)](https://en.wikipedia.org/wiki/Content_Security_Policy) and proxy support, meaning you can use it over [Tor](self-contained-networks.md#tor).

    [:octicons-home-16: Homepage](https://hyliu.me/fluent-reader){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://github.com/yang991178/fluent-reader/wiki/Privacy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://github.com/yang991178/fluent-reader/wiki/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/yang991178/fluent-reader){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://github.com/sponsors/yang991178){ .card-link title=Contribute }

    ??? downloads

        [:fontawesome-brands-windows:](https://hyliu.me/fluent-reader){ .card-link title=Windows }
        [:fontawesome-brands-app-store:](https://apps.apple.com/app/id1520907427){ .card-link title="Mac App Store" }

### GNOME Feeds

!!! recommendation

    ![GNOME Feeds logo](assets/img/news-aggregators/gfeeds.svg){ align=right }

    **GNOME Feeds** is an [RSS](https://en.wikipedia.org/wiki/RSS) and [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) news reader for [GNOME](https://www.gnome.org). It has a simple interface and is quite fast.

    [:octicons-home-16: Homepage](https://gfeeds.gabmus.org){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.gnome.org/World/gfeeds){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://liberapay.com/gabmus/){ .card-link title=Contribute }

    ??? downloads

        [:fontawesome-brands-linux:](https://gfeeds.gabmus.org/#install){ .card-link title=Linux }
        [:pg-flathub:](https://flathub.org/apps/details/org.gabmus.gfeeds){ .card-link title=Flatpak }

### Akregator

!!! recommendation

    ![Akregator logo](assets/img/news-aggregators/akregator.svg){ align=right }

    **Akregator** is a news feed reader that is a part of the [KDE](https://kde.org) project. It comes with a fast search, advanced archiving functionality and an internal browser for easy news reading.

    [:octicons-home-16: Homepage](https://apps.kde.org/akregator){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://kde.org/privacypolicy-apps){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://docs.kde.org/?application=akregator){ .card-link title=Documentation}
    [:octicons-code-16:](https://invent.kde.org/pim/akregator){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://kde.org/community/donations/){ .card-link title=Contribute }

    ??? downloads

        [:pg-flathub:](https://flathub.org/apps/details/org.kde.akregator){ .card-link title=Flatpak }

### Feeder

!!! recommendation

    ![Feeder logo](assets/img/news-aggregators/feeder.png){ align=right }

    **Feeder** is a modern RSS client for Android that has many [features](https://gitlab.com/spacecowboy/Feeder#features) and works well with folders of RSS feeds. It supports it supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) and [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-repo-16: Repository](https://gitlab.com/spacecowboy/Feeder){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.com/spacecowboy/Feeder){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://ko-fi.com/spacecowboy){ .card-link title=Contribute }

    ??? downloads

        [:fontawesome-brands-google-play:](https://play.google.com/store/apps/details?id=com.nononsenseapps.feeder.play){ .card-link title="Google Play" }
        [:pg-f-droid:](https://f-droid.org/en/packages/com.nononsenseapps.feeder/){ .card-link title=F-Droid }

### NetNewsWire

!!! recommendation

    ![NetNewsWire logo](assets/img/news-aggregators/netnewswire.png){ align=right }

    **NetNewsWire** a free and open-source feed reader for macOS and iOS with a focus on a native design and feature set. It supports the typical feed formats alongside built-in support for Twitter and Reddit feeds.

    [:octicons-home-16: Homepage](https://netnewswire.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://netnewswire.com/privacypolicy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://netnewswire.com/help/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/Ranchero-Software/NetNewsWire){ .card-link title="Source Code" }

    ??? downloads

        [:fontawesome-brands-apple:](https://netnewswire.com){ .card-link title=macOS }
        [:fontawesome-brands-app-store-ios:](https://apps.apple.com/us/app/netnewswire-rss-reader/id1480640210){ .card-link title="App Store" }

### Miniflux

!!! recommendation

    ![Miniflux logo](assets/img/news-aggregators/miniflux.svg#only-light){ align=right }
    ![Miniflux logo](assets/img/news-aggregators/miniflux-dark.svg#only-dark){ align=right }

    **Miniflux** is a web-based news aggregator that you can self-host. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-home-16: Homepage](https://miniflux.app){ .md-button .md-button--primary }
    [:octicons-info-16:](https://miniflux.app/docs/index.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/miniflux/v2){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://miniflux.app/#donations){ .card-link title=Contribute }

### Newsboat

!!! recommendation

    ![Newsboat logo](assets/img/news-aggregators/newsboat.svg){ align=right }

    **Newsboat** is an RSS/Atom feed reader for the text console. It's an actively maintained fork of [Newsbeuter](https://en.wikipedia.org/wiki/Newsbeuter). It is very lightweight, and ideal for use over [Secure Shell](https://en.wikipedia.org/wiki/Secure_Shell).

    [:octicons-home-16: Homepage](https://newsboat.org){ .md-button .md-button--primary }
    [:octicons-info-16:](https://newsboat.org/releases/2.27/docs/newsboat.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/newsboat/newsboat){ .card-link title="Source Code" }

## Social media that supports RSS

Some social media services also support RSS although it's not often advertised.

### YouTube

You can subscribe YouTube channels without logging in and associating usage information with your Google Account.

!!! example

    To subscribe to a YouTube channel with an RSS client, first look for your [channel code](https://support.google.com/youtube/answer/6180214), replace `channel_id` below:
    ```text
    https://www.youtube.com/feeds/videos.xml?channel_id={{ channel id }}
    ```

### Reddit

Reddit also supports subscription via RSS.

!!! example
    Replace `subreddit_name` with the subreddit you wish to subscribe to.

    ```text
    https://www.reddit.com/r/{{ subreddit_name }}/new/.rss
    ```

### Twitter

Using any of the Nitter [instances](https://github.com/zedeus/nitter/wiki/Instances) you can easily subscribe using RSS.

!!! example
    1. Pick an instance and set `nitter_instance`.
    2. Replace `twitter_account` with the account name.

       ```text
       https://{{ nitter_instance }}/{{ twitter_account }}/rss
       ```

==> v2.26.zip: privacyguides.org/docs/news-aggregators.en.md <==
---
title: "News Aggregators"
icon: material/rss
---

A [news aggregator](https://en.wikipedia.org/wiki/News_aggregator) is a way to keep up with your favourite blogs and news sites.

## Aggregator clients

### Akregator

!!! recommendation

    ![Akregator logo](assets/img/news-aggregators/akregator.svg){ align=right }

    **Akregator** is a news feed reader that is a part of the [KDE](https://kde.org) project. It comes with a fast search, advanced archiving functionality and an internal browser for easy news reading.

    [:octicons-home-16: Homepage](https://apps.kde.org/akregator){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://kde.org/privacypolicy-apps){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://docs.kde.org/?application=akregator){ .card-link title=Documentation}
    [:octicons-code-16:](https://invent.kde.org/pim/akregator){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://kde.org/community/donations/){ .card-link title=Contribute }

    ??? downloads

        - [:simple-flathub: Flatpak](https://flathub.org/apps/details/org.kde.akregator)

### Feeder

!!! recommendation

    ![Feeder logo](assets/img/news-aggregators/feeder.png){ align=right }

    **Feeder** is a modern RSS client for Android that has many [features](https://gitlab.com/spacecowboy/Feeder#features) and works well with folders of RSS feeds. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-repo-16: Repository](https://gitlab.com/spacecowboy/Feeder){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.com/spacecowboy/Feeder){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://ko-fi.com/spacecowboy){ .card-link title=Contribute }

    ??? downloads

        - [:simple-googleplay: Google Play](https://play.google.com/store/apps/details?id=com.nononsenseapps.feeder.play)
        - [:simple-fdroid: F-Droid](https://f-droid.org/en/packages/com.nononsenseapps.feeder/)

### Fluent Reader

!!! recommendation

    ![Fluent Reader logo](assets/img/news-aggregators/fluent-reader.svg){ align=right }

    **Fluent Reader** is a secure cross-platform news aggregator that has useful privacy features such as deletion of cookies on exit, strict [content security policies (CSP)](https://en.wikipedia.org/wiki/Content_Security_Policy) and proxy support, meaning you can use it over [Tor](tor.md).

    [:octicons-home-16: Homepage](https://hyliu.me/fluent-reader){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://github.com/yang991178/fluent-reader/wiki/Privacy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://github.com/yang991178/fluent-reader/wiki/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/yang991178/fluent-reader){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://github.com/sponsors/yang991178){ .card-link title=Contribute }

    ??? downloads

        - [:simple-windows11: Windows](https://hyliu.me/fluent-reader)
        - [:simple-apple: Mac App Store](https://apps.apple.com/app/id1520907427)

### GNOME Feeds

!!! recommendation

    ![GNOME Feeds logo](assets/img/news-aggregators/gfeeds.svg){ align=right }

    **GNOME Feeds** is an [RSS](https://en.wikipedia.org/wiki/RSS) and [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) news reader for [GNOME](https://www.gnome.org). It has a simple interface and is quite fast.

    [:octicons-home-16: Homepage](https://gfeeds.gabmus.org){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.gnome.org/World/gfeeds){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://liberapay.com/gabmus/){ .card-link title=Contribute }

    ??? downloads

        - [:simple-linux: Linux](https://gfeeds.gabmus.org/#install)
        - [:simple-flathub: Flatpak](https://flathub.org/apps/details/org.gabmus.gfeeds)

### Miniflux

!!! recommendation

    ![Miniflux logo](assets/img/news-aggregators/miniflux.svg#only-light){ align=right }
    ![Miniflux logo](assets/img/news-aggregators/miniflux-dark.svg#only-dark){ align=right }

    **Miniflux** is a web-based news aggregator that you can self-host. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-home-16: Homepage](https://miniflux.app){ .md-button .md-button--primary }
    [:octicons-info-16:](https://miniflux.app/docs/index.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/miniflux/v2){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://miniflux.app/#donations){ .card-link title=Contribute }

### NetNewsWire

!!! recommendation

    ![NetNewsWire logo](assets/img/news-aggregators/netnewswire.png){ align=right }

    **NetNewsWire** a free and open-source feed reader for macOS and iOS with a focus on a native design and feature set. It supports the typical feed formats alongside built-in support for Twitter and Reddit feeds.

    [:octicons-home-16: Homepage](https://netnewswire.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://netnewswire.com/privacypolicy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://netnewswire.com/help/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/Ranchero-Software/NetNewsWire){ .card-link title="Source Code" }

    ??? downloads

        - [:simple-apple: macOS](https://netnewswire.com)
        - [:simple-appstore: App Store](https://apps.apple.com/us/app/netnewswire-rss-reader/id1480640210)

### Newsboat

!!! recommendation

    ![Newsboat logo](assets/img/news-aggregators/newsboat.svg){ align=right }

    **Newsboat** is an RSS/Atom feed reader for the text console. It's an actively maintained fork of [Newsbeuter](https://en.wikipedia.org/wiki/Newsbeuter). It is very lightweight, and ideal for use over [Secure Shell](https://en.wikipedia.org/wiki/Secure_Shell).

    [:octicons-home-16: Homepage](https://newsboat.org){ .md-button .md-button--primary }
    [:octicons-info-16:](https://newsboat.org/releases/2.27/docs/newsboat.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/newsboat/newsboat){ .card-link title="Source Code" }

## Social Media RSS Support

Some social media services also support RSS although it's not often advertised.

### Reddit

Reddit allows you to subscribe to subreddits via RSS.

!!! example
    Replace `subreddit_name` with the subreddit you wish to subscribe to.

    ```text
    https://www.reddit.com/r/{{ subreddit_name }}/new/.rss
    ```

### Twitter

Using any of the Nitter [instances](https://github.com/zedeus/nitter/wiki/Instances) you can easily subscribe using RSS.

!!! example
    1. Pick an instance and set `nitter_instance`.
    2. Replace `twitter_account` with the account name.

       ```text
       https://{{ nitter_instance }}/{{ twitter_account }}/rss
       ```

### YouTube

You can subscribe YouTube channels without logging in and associating usage information with your Google Account.

!!! example

    To subscribe to a YouTube channel with an RSS client, first look for your [channel code](https://support.google.com/youtube/answer/6180214), replace `[CHANNEL ID]` below:
    ```text
    https://www.youtube.com/feeds/videos.xml?channel_id=[CHANNEL ID]
    ```
